pub struct Pipeline<S> { /* private fields */ }Expand description
A completed execution chain that can process data.
Use Pipeline::builder to construct a new instance.
Implementations
Sourceimpl Pipeline<()>
impl Pipeline<()>
Sourcepub fn builder<I>() -> PipelineBuilder<NoOp<I>>
pub fn builder<I>() -> PipelineBuilder<NoOp<I>>
Starts the construction of a new pipeline.
To ensure type safety, the user must specify the initial input type:
Pipeline::builder::<i32>()
Sourceimpl<S> Pipeline<S>where
S: Step + 'static,
impl<S> Pipeline<S>where
S: Step + 'static,
Sourcepub fn into_boxed(self) -> Box<dyn Step<Input = S::Input, Output = S::Output>>
pub fn into_boxed(self) -> Box<dyn Step<Input = S::Input, Output = S::Output>>
Erases the concrete type of the pipeline, returning a boxed trait object. This is useful for storing different pipelines in a single collection as long as they share the same Input and Output types. The matching types can be bypassed by creating an Enum Wrapper of known Stages.