Crate static_conduit

Crate static_conduit 

Conduit

conduit is a type-safe, zero-cost pipeline engine designed for structured data transformation.

It uses a recursive, static-dispatch architecture to ensure that the entire transformation chain is validated at compile-time with no runtime overhead.

Modules

prelude

Structs

Pipeline
A completed execution chain that can process data.
PipelineBuilder
A utility for assembling Step implementations into a linear chain.
Retry
A configuration for retrying a Step when encountering recoverable errors.

Enums

PipelineError
Represents the various error states a pipeline stage can encounter.

Traits

Policy
Policy trait, decorates a step with some extra behavior, such as retrying or logging
Step
The core trait for all transformation logic.