Pipeline

Struct Pipeline 

pub struct Pipeline<S> { /* private fields */ }
A completed execution chain that can process data.

Use Pipeline::builder to construct a new instance.

Implementations

Source

impl Pipeline<()>

pub fn builder<I>() -> PipelineBuilder<NoOp<I>>

Starts the construction of a new pipeline.

To ensure type safety, the user must specify the initial input type: Pipeline::builder::<i32>()

Source

impl<S> Pipeline<S>
where S: Step,

pub fn run(&self, input: S::Input) -> Result<S::Output, PipelineError>

Feeds data into the start of the pipeline and returns the final result.

This method executes all stages sequentially. Execution stops upon completion or on PipelineError

Source

impl<S> Pipeline<S>
where S: Step + 'static,

pub fn into_boxed(self) -> Box<dyn Step<Input = S::Input, Output = S::Output>>

Erases the concrete type of the pipeline, returning a boxed trait object. This is useful for storing different pipelines in a single collection as long as they share the same Input and Output types. The matching types can be bypassed by creating an Enum Wrapper of known Stages.