pub struct PipelineBuilder<S> { /* private fields */ }Expand description
A utility for assembling Step implementations into a linear chain.
Implementations
Sourceimpl<S> PipelineBuilder<S>where
S: Step,
impl<S> PipelineBuilder<S>where
S: Step,
Sourcepub fn add_stage<A>(self, action: A) -> PipelineBuilder<PipelineStep<S, A>>
pub fn add_stage<A>(self, action: A) -> PipelineBuilder<PipelineStep<S, A>>
Appends a new stage to the end of the current pipeline.
Sourcepub fn add_map<F, O>(
self,
f: F,
) -> PipelineBuilder<PipelineStep<S, ClosureStep<F, S::Output, O>>>
pub fn add_map<F, O>( self, f: F, ) -> PipelineBuilder<PipelineStep<S, ClosureStep<F, S::Output, O>>>
Appends a closure-based transformation to the pipeline.