pub trait Policy<S: Step> {
type Decorated: Step<Input = S::Input, Output = S::Output>;
// Required method
fn apply(self, step: S) -> Self::Decorated;
}Expand description
Policy trait, decorates a step with some extra behavior, such as retrying or logging
Any struct implementing Policy can be plugged into a Pipeline.